/*******************************************************************************
 * @file filed_mapping.cpp
 * @brief tqsdk2 和 fclib 部分字段映射声明文件
 * @copyright 上海信易信息科技股份有限公司 版权所有
 ******************************************************************************/
#include "field_mapping.h"

Direction GetDirection(const std::string& direction) {
  if (!direction.compare("BUY")) {
    return Direction::kBuy;
  } else if (!direction.compare("SELL")) {
    return Direction::kSell;
  } else {
    throw std::invalid_argument("下单方向 " + direction + " 错误, 请检查 direction 参数是否填写正确.");
  }
}

std::string GetDirection(Direction d) {
  switch (d) {
    case Direction::kBuy: return "BUY";
    case Direction::kSell: return "SELL";
    default: return "Unknown DIRECTION_TYPE";
  }
}

Offset GetOffSet(const std::string& offset) {
  if (!offset.compare("OPEN") || !offset.compare("kOpen")) {
    return Offset::kOpen;
  } else if (!offset.compare("CLOSE") || !offset.compare("kClose")) {
    return Offset::kClose;
  } else if (!offset.compare("CLOSETODAY") || !offset.compare("kCloseToday")) {
    return Offset::kCloseToday;
  } else {
    throw std::invalid_argument("开平标志 " + offset + " 错误, 请检查 offset 是否填写正确.");
  }
}

std::string GetOffSet(Offset o) {
  switch (o) {
    case Offset::kOpen: return "OPEN";
    case Offset::kClose: return "CLOSE";
    case Offset::kCloseToday: return "CLOSETODAY";
    default: return "Unknown OFFSET_TYPE";
  }
}

ProductClass GetProduct(const std::string& product_class) {
  if (!product_class.compare("CONT")) {
    return ProductClass::kCont;
  } else if (!product_class.compare("FUTURE")) {
    return ProductClass::kFuture;
  } else if (!product_class.compare("OPTION")) {
    return ProductClass::kOption;
  } else if (!product_class.compare("COMBINE")) {
    return ProductClass::kCombine;
  } else if (!product_class.compare("INDEX")) {
    return ProductClass::kIndex;
  } else if (!product_class.compare("STOCK")) {
    return ProductClass::kStock;
  } else if (!product_class.compare("FUND")) {
    return ProductClass::kFund;
  } else {
    throw std::invalid_argument("合约类型 " + product_class + " 错误, 请检查 ins_class 参数是否填写正确.");
  }
}

OptionClass GetOptionClass(const std::string& option_class) {
  if (!option_class.compare("CALL")) {
    return OptionClass::kCall;
  } else if (!option_class.compare("PUT")) {
    return OptionClass::kPut;
  } else {
    throw std::invalid_argument("期权类型 " + option_class + " 错误, 请检查 option_class 参数是否填写正确.");
  }
}

std::string GetTradeStatus(TradeStatus ts) {
  switch (ts) {
    case TradeStatus::kBeforeTrading: return "BEFORETRADING";
    case TradeStatus::kAuctionOrdering: return "AUCTIONORDERING";
    case TradeStatus::kAuctionBalance: return "AUCTIONBALANCE";
    case TradeStatus::kAuctionMatch: return "AUCTIONMATCH";
    case TradeStatus::kContinous: return "CONTINOUS";
    case TradeStatus::kNoTrading: return "NOTRADING";
    case TradeStatus::kClosed: return "CLOSED";
    default: return "";
  }
}